/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tika.fork;

import java.io.IOException;
import java.io.InputStream;
import java.util.Collections;
import java.util.Set;

import org.apache.tika.exception.TikaException;
import org.apache.tika.fork.unusedpackage.ClassInUnusedPackage;
import org.apache.tika.metadata.Metadata;
import org.apache.tika.mime.MediaType;
import org.apache.tika.parser.AbstractParser;
import org.apache.tika.parser.ParseContext;
import org.apache.tika.sax.XHTMLContentHandler;
import org.junit.Assert;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

class ForkTestParser extends AbstractParser {

    /** Serial version UID */
    private static final long serialVersionUID = -5492269783593452319L;

    public Set<MediaType> getSupportedTypes(ParseContext context) {
        return Collections.singleton(MediaType.TEXT_PLAIN);
    }

    public void parse(
            InputStream stream, ContentHandler handler,
            Metadata metadata, ParseContext context)
            throws IOException, SAXException, TikaException {
        stream.read();

        metadata.set(Metadata.CONTENT_TYPE, "text/plain");

        XHTMLContentHandler xhtml = new XHTMLContentHandler(handler, metadata);
        xhtml.startDocument();
        char[] ch = "Hello, World!".toCharArray();
        xhtml.characters(ch, 0, ch.length);
        xhtml.endDocument();
    }

    static class ForkTestParserAccessingPackage extends ForkTestParser {
        @Override
        public void parse(InputStream stream, ContentHandler handler, Metadata metadata,
                          ParseContext context) throws IOException, SAXException, TikaException {
            Assert.assertNotNull(ClassInUnusedPackage.class.getPackage());
            super.parse(stream, handler, metadata, context);
        }
    }
}